@@ -22,6 +22,8 @@
 
 #include "pa_utils.h"
 
+#include <math.h>
+
 #include <QDate>
 #include <QLineEdit>
 #include <QSettings>
@@ -49,7 +51,10 @@ MainWindow::MainWindow(QWidget *parent) :
     QCoreApplication::setApplicationName("VU Meter");
 
     QSettings settings;
-    meter = settings.value(SettingsDialog::METER, 0).toInt();
+    meter = settings.value(SettingsDialog::METER,
+                           SettingsDialog::METER_DEFAULT).toInt();
+    interpolationLevel = settings.value(SettingsDialog::INTERPOLATION_LEVEL,
+                                        SettingsDialog::INTERPOLATION_LEVEL_DEFAULT).toInt();
 
     ui->setupUi(this);
 
@@ -82,9 +87,9 @@ MainWindow::MainWindow(QWidget *parent) :
     connect(ui->sourcesComboBox, SIGNAL(activated(int)), this, SLOT(sourceChanged(int)));
 
 #ifdef Q_WS_MAEMO_5
-    connect_to_vu_meter_stream("source.hw0", this);
+    connect_to_vu_meter_stream("source.hw0", this, pow(2, interpolationLevel));
 #else
-    connect_to_vu_meter_stream(sources->at(0).toLocal8Bit().constData(), this);
+    connect_to_vu_meter_stream(sources->at(0).toLocal8Bit().constData(), this, pow(2, interpolationLevel));
 #endif
 
     connect(this, SIGNAL(updateVuMeterSignal(float)), this, SLOT(updateValues(float)), Qt::QueuedConnection);
@@ -121,37 +126,55 @@ MainWindow::~MainWindow()
 
 void MainWindow::applySettings(){
     QSettings settings;
-    triggerValue = settings.value(SettingsDialog::TRIGGER_VALUE, 0).toInt();
-    triggerCommand = settings.value(SettingsDialog::TRIGGER_COMMAND, "").toString();
-    triggerCountSetting = settings.value(SettingsDialog::TRIGGER_COUNT, 0).toInt();
+    triggerValue = settings.value(SettingsDialog::TRIGGER_VALUE,
+                                  SettingsDialog::TRIGGER_VALUE_DEFAULT).toInt();
+    triggerCommand = settings.value(SettingsDialog::TRIGGER_COMMAND,
+                                    SettingsDialog::TRIGGER_COMMAND_DEFAULT).toString();
+    triggerCountSetting = settings.value(SettingsDialog::TRIGGER_COUNT,
+                                         SettingsDialog::TRIGGER_COUNT_DEFAULT).toInt();
 
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5AutoOrientation,
-                 settings.value(SettingsDialog::AUTO_ROTATE, false).toBool());
+                 settings.value(SettingsDialog::AUTO_ROTATE,
+                                SettingsDialog::AUTO_ROTATE_DEFAULT).toBool());
 #endif
 
     volumeMeterWidget->setTriggerValue(triggerValue);
     volumeMeterWidget->setUseColoredScale(settings.value(SettingsDialog::COLOR_SCALE, false).toBool());
-    volumeMeterWidget->setColors(settings.value(SettingsDialog::COLOR_LOWER_COLOR, QColor(Qt::green)).value<QColor>(),
-                                 settings.value(SettingsDialog::COLOR_MID_COLOR, QColor(Qt::yellow)).value<QColor>(),
-                                 settings.value(SettingsDialog::COLOR_UPPER_COLOR, QColor(Qt::red)).value<QColor>());
-    volumeMeterWidget->setColorThresholds(settings.value(SettingsDialog::COLOR_LOWER_THRESHOLD, 60).toInt(),
-                                          settings.value(SettingsDialog::COLOR_UPPER_THRESHOLD, 95).toInt());
+    volumeMeterWidget->setColors(settings.value(SettingsDialog::COLOR_LOWER_COLOR,
+                                                SettingsDialog::COLOR_LOWER_COLOR_DEFAULT).value<QColor>(),
+                                 settings.value(SettingsDialog::COLOR_MID_COLOR,
+                                                SettingsDialog::COLOR_MID_COLOR_DEFAULT).value<QColor>(),
+                                 settings.value(SettingsDialog::COLOR_UPPER_COLOR,
+                                                SettingsDialog::COLOR_UPPER_COLOR_DEFAULT).value<QColor>());
+    volumeMeterWidget->setColorThresholds(settings.value(SettingsDialog::COLOR_LOWER_THRESHOLD,
+                                                         SettingsDialog::COLOR_LOWER_THRESHOLD_DEFAULT).toInt(),
+                                          settings.value(SettingsDialog::COLOR_UPPER_THRESHOLD,
+                                                         SettingsDialog::COLOR_UPPER_THRESHOLD_DEFAULT).toInt());
 
-    loggingEnabled = settings.value(SettingsDialog::LOG_LOGGING_ENABLED, false).toBool();
-    logFileName = settings.value(SettingsDialog::LOG_FILE_NAME, tr("Select File")).toString();
+    loggingEnabled = settings.value(SettingsDialog::LOG_LOGGING_ENABLED,
+                                    SettingsDialog::LOG_LOGGING_ENABLED_DEFAULT).toBool();
+    logFileName = settings.value(SettingsDialog::LOG_FILE_NAME,
+                                 SettingsDialog::LOG_FILE_NAME_DEFAULT).toString();
 
     if(loggingEnabled){
         if(logFile != NULL && logFile->fileName().compare(logFileName) != 0){
             closeFile(logFile);
         }
 
-        if(logFile == NULL){
+        if(logFile == NULL && logFileName.compare(SettingsDialog::LOG_FILE_NAME_DEFAULT) != 0){
             logIndex = 0;
             logFile = new QFile(logFileName);
             logFile->open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::Text);
         }
     }
+
+    int ipolLevel = settings.value(SettingsDialog::INTERPOLATION_LEVEL,
+                                   SettingsDialog::INTERPOLATION_LEVEL_DEFAULT).toInt();
+    if(interpolationLevel != ipolLevel){
+        interpolationLevel = ipolLevel;
+        sourceChanged(ui->sourcesComboBox->currentIndex());
+    }
 }
 
 void MainWindow::closeFile(QFile *file){
@@ -189,6 +212,10 @@ void MainWindow::changeMeter(){
     connect(volumeMeterWidget, SIGNAL(clicked()), this, SLOT(changeMeter()));
 }
 
+bool MainWindow::getInterpolationEnabled(){
+    return interpolationLevel != 0;
+}
+
 void MainWindow::processFinished(){
     if(process != NULL){
         process->deleteLater();
@@ -228,19 +255,19 @@ void MainWindow::sourceChanged(int index){
 #ifdef Q_WS_MAEMO_5
     switch(index){
     case 0:
-        connect_to_vu_meter_stream("source.hw0", this);
+        connect_to_vu_meter_stream("source.hw0", this, pow(2, interpolationLevel));
         break;
     case 1:
-        connect_to_vu_meter_stream("source.hw1", this);
+        connect_to_vu_meter_stream("source.hw1", this, pow(2, interpolationLevel));
         break;
     case 2:
-        connect_to_vu_meter_stream("sink.hw0.monitor", this);
+        connect_to_vu_meter_stream("sink.hw0.monitor", this, pow(2, interpolationLevel));
         break;
     default:
         qDebug("Unknown source!");
     }
 #else
-    connect_to_vu_meter_stream(sources->at(index).toLocal8Bit().constData(), this);
+    connect_to_vu_meter_stream(sources->at(index).toLocal8Bit().constData(), this, pow(2, interpolationLevel));
 #endif
 }
 
