@@ -39,6 +39,7 @@ public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
 
+    bool getInterpolationEnabled();
     void updateVuMeter(const float *data);
 
 signals:
@@ -47,6 +48,8 @@ signals:
 private:
     Ui::MainWindow *ui;
 
+    int interpolationLevel;
+
     bool loggingEnabled;
     QString logFileName;
     QFile *logFile;
