@@ -28,7 +28,7 @@
 
 extern pa_stream *stream;
 
-void connect_to_vu_meter_stream(const char *source, MainWindow *vuMeter);
+void connect_to_vu_meter_stream(const char *source, MainWindow *vuMeter, int numberOfSamples = 1);
 void disconnect_stream();
 
 void stream_read_callback(pa_stream *stream, size_t length, void *data);
