@@ -52,22 +52,22 @@ void VolumeLineChartWidget::draw(QPainter *painter){
             if(dbUnit){
                 val *= MAX_DB;
 
-                if(val < 60){
-                    pen.setColor(Qt::green);
-                }else if (val < 95){
-                    pen.setColor(Qt::yellow);
+                if(val < lowerThreshold){
+                    pen.setColor(lowerColor);
+                }else if (val < upperThreshold){
+                    pen.setColor(midColor);
                 }else{
-                    pen.setColor(Qt::red);
+                    pen.setColor(upperColor);
                 }
             }else{
                 val *= MAX_LINEAR;
 
-                if(val < 100){
-                    pen.setColor(Qt::green);
-                }else if (val < 150){
-                    pen.setColor(Qt::yellow);
+                if(val < lowerThreshold){
+                    pen.setColor(lowerColor);
+                }else if (val < upperThreshold){
+                    pen.setColor(midColor);
                 }else{
-                    pen.setColor(Qt::red);
+                    pen.setColor(upperColor);
                 }
             }
 
